import { Link, Head } from "@inertiajs/react";
import hero from "../assets/img/hero.webp";
import { Typewriter } from "react-simple-typewriter";
import Heading from "@/Components/Heading";
import "../assets/welcome.css";
import path from "../assets/img/trading.jpg";
import PhoneField from "@/Components/PhoneField";
import apple from "../assets/img/apple.svg";
import playstore from "../assets/img/playstore.svg";
import twitter from "../assets/img/twitter.svg";
import fb from "../assets/img/fb.svg";
import ig from "../assets/img/ig.svg";
import yt from "../assets/img/yt.svg";
import Lottie from 'lottie-react';
import animationData from '../assets/lottie/lottie.json';


export default function Welcome(props) {
  const testimonials = [
    {
      icon: "trading.jpg",
      testimonial:
        "I took the Way2Laabh Stock Market Course and it was one of the best decisions I've made for my financial future. The instructors were incredibly knowledgeable and patient, and the course material was presented in a clear and concise way. I feel much more confident making investment decisions now that I've completed the course.",
      image: "Aryan_Ali.png",
      name: "Aryan Ali",
    },
    {
      icon: "trading.jpg",
      testimonial:
        "I highly recommend the Way2Laabh Stock Market Course to anyone who wants to learn more about investing in the stock market. The instructors are excellent and the course content is comprehensive. I learned a lot about technical analysis, fundamental analysis, and risk management strategies. Thanks to this course, I've been able to make smarter investment decisions and see real results.",
      image: "Arman_Singh.png",
      name: "Arman Singh",
    },
    {
      icon: "trading.jpg",
      testimonial:
        "The Way2Laabh Stock Market Course exceeded my expectations. The instructors were engaging and knowledgeable, and the course material was presented in a way that was easy to understand. The course covered everything from the basics of investing to more advanced concepts like portfolio management. I feel much more confident investing in the stock market now that I've completed this course.",
      image: "Dinesh_Kapoor.png",
      name: "Dinesh Kapoor",
    },
    {
      icon: "trading.jpg",
      testimonial:
        "I took the Way2Laabh Stock Market Course as a beginner with no prior experience in investing, and I was pleasantly surprised by how much I learned. The course was well-structured and the instructors were patient and supportive. I now have a solid understanding of how the stock market works and feel confident in making investment decisions on my own.",
      image: "Dev_Patel.png",
      name: "Dev Patel",
    },
    {
      icon: "trading.jpg",
      testimonial:
        "The Way2Laabh Stock Market Course is an excellent investment for anyone who wants to take control of their financial future. The instructors are experienced and knowledgeable, and the course material is comprehensive and up-to-date. I learned a lot about how to analyze stocks, read financial statements, and manage risk. I highly recommend this course to anyone who wants to become a successful investor.",
      image: "Farah_Khan.png",
      name: "Farah Khan",
    },
    {
      icon: "trading.jpg",
      testimonial:
        "I had been interested in the stock market for a while but never knew where to start. The Way2Laabh Stock Market Course was the perfect introduction for me. The instructors were patient and knowledgeable, and the course material was presented in a way that was easy to understand. I now have the confidence to start investing on my own and am excited to see where it takes me.",
      image: "Karan_Kapoor.png",
      name: "Karan Kapoor",
    },
    {
      icon: "trading.jpg",
      testimonial:
        "I've taken several investing courses in the past, but the Way2Laabh Stock Market Course was by far the best. The instructors were engaging and made the material interesting, and the course covered everything from the basics to more advanced topics like options trading. I especially appreciated the emphasis on risk management and portfolio diversification. This course has helped me become a more informed and confident investor.",
      image: "Mahir_Gupta.png",
      name: "Mahir Gupta",
    },
    {
      icon: "trading.jpg",
      testimonial:
        "I had some experience investing in the stock market, but I wanted to take my knowledge to the next level. The Way2Laabh Stock Market Course was exactly what I was looking for. The instructors were experienced and provided valuable insights, and the course material was well-organized and easy to follow. I now have a better understanding of technical analysis and can make more informed investment decisions.",
      image: "Farhan_Sheikh.webp",
      name: "Farhan Sheikh",
    },
    {
      icon: "trading.jpg",
      testimonial:
        "The Way2Laabh Stock Market Course was a great investment for me. The instructors were knowledgeable and passionate about investing, and the course material was comprehensive and practical. I especially appreciated the focus on long-term investing and building a diversified portfolio. This course has helped me become a smarter and more disciplined investor.",
      image: "client-06.png",
      name: "Chahat Mehta",
    },
  ];

  return (
    <>
      <Head title="Finroots" />
      <div className="overflow-hidden">
        <div className="min-h-screen flex flex-col bg-white font-sans">
          {/* Navbar */}
          <div className="container">
            <header className="w-full flex justify-between items-center px-8 pl-0 py-4">
              <h1 className="text-xl font-bold text-gray-800">finroots</h1>
              <div className="space-x-4">
                <button className="px-4 py-2 bg-[#4C9A2A] text-white rounded">
                  Download App
                </button>
                <Link href="/login" className="px-4 py-2 border border-[#4C9A2A] text-[#4C9A2A] rounded">
                  Login
                </Link>
              </div>
            </header>
          </div>

          {/* Main Section */}
          <section className="hero-section">
            <div className="container">
              <div className="flex flex-col lg:flex-row items-center justify-between py-16 space-y-8 lg:space-y-0">
                {/* Left Text Section */}
                <div className="lg:w-1/2 lg:text-left w-full">
                  <h2 className="text-[52px] font-bold text-[#022b69] font-inter">
                    Every{" "}
                    <Typewriter
                      words={["stock", "investor", "opportunity", "analysis"]}
                      loop={true}
                      cursor
                      cursorStyle="|"
                      typeSpeed={70}
                      deleteSpeed={50}
                      delaySpeed={1000}
                    />
                  </h2>
                  <Heading
                    title="needs a finroots"
                    subcontent="Finroots is a place where traders and investors can connect with
              each other, share their ideas, and learn from each other."
                  />

                  <p className="text-sm text-[#8095b4] mt-2 font-inter">
                    Disclaimer: Finroots's content is not financial advice.{" "}
                    <a href="#" className="text-[#4C9A2A]">
                      Learn more
                    </a>
                  </p>

                  {/* Input Field */}
                  <PhoneField />
                </div>

                {/* Right Image Section */}
                <div className="lg:w-1/2 w-full flex justify-center relative">
                  <div className="absolute inset-0 bg-blue-100 opacity-20 rounded-full blur-lg"></div>
                  <div className="flex space-x-8">
                    {/* Left Image */}
                    <div className="relative">
                      {/* <img
                        src={hero}
                        alt="Hero"
                        className="rounded-lg w-[500px]"
                      /> */}
                            <Lottie animationData={animationData} loop={true} />

                    </div>
                  </div>
                </div>
              </div>
            </div>
          </section>
          <section className="connect--section">
            <div className="container">
              <div className="lg:w-3/5 w-full mx-auto">
                <Heading
                  title="Connect with investors from all over India"
                  textcenter="text-center"
                  subcontent="Browse thousands of trades, charts, discussions, insights..
"
                />
              </div>
            </div>
          </section>

          <section className="connect--section mt-5 pt-28 pb-28 bg-[#f2f6ff]">
            <div className="container">
              <div className="lg:w-3/5 w-full mx-auto pb-5">
                <Heading
                  title="Backed By Top Investors And Founders
"
                  textcenter="text-center"
                />
              </div>
              <div className="relative">
                {/* <div className="bg-[#f2f6ff] z-[1] absolute left-0 right-0 top-0 bottom-0 mx-auto"></div> */}
                <div className="scroll-animation-wrapper no-overlay mt--50">
                  <div className="scroll-animation scroll-right-left ">
                    {testimonials.map((testimonial, index) => (
                      <div
                        key={index}
                        className="single-column-20 bg-theme-gradient-odd"
                      >
                        <div className="rbt-testimonial-box style-2">
                          <div className="inner">
                            <div className="flex gap-3 pb-4 pt-4 ">
                              <div className="icons w-10 rounded-full overflow-hidden">
                                <img src={path} alt="Clint Images" />
                              </div>
                              <div className="flex flex-col">
                                <div className="text-sm font-bold">
                                  {testimonial.name}
                                </div>
                                <div className="flex gap-2 text-[#022b6980]">
                                  <span className="text-xs">
                                    Reputation: 135,581
                                  </span>
                                  <span className="text-xs">
                                    Nov 29 2:20 PM
                                  </span>
                                </div>
                              </div>
                            </div>
                            <div className="subcontent flex"></div>
                            <div className="description">
                              <p className="subtitle-3 text-sm">
                                {testimonial.testimonial}
                              </p>
                            </div>
                          </div>
                        </div>
                      </div>
                    ))}
                  </div>
                </div>
              </div>
            </div>
          </section>
          <footer className="cta--section">
            <div className="container">
              <div className="lg:flex justify-between py-20 items-center">
                <div className="lg:w-1/2 w-full">
                  <div className="text-2xl font-bold">Finroots</div>
                  <div className="text-3xl font-inter mt-2 font-medium">
                    Join the 10 lakh strong community today
                  </div>
                  <div className="flex mt-4 space-x-3">
                    <a href="#" className="">
                      <img src={apple} alt="App Store" className="" />
                    </a>
                    <a href="#" className="">
                      <img src={playstore} alt="Play Store" className="" />
                    </a>
                  </div>
                </div>
                <div className="lg:w-1/2 w-full">
                  <div className="flex lg:justify-end justify-center">
                    <PhoneField />
                  </div>
                  <div className="flex items-center justify-center mt-5 space-x-4">
                    <span className="text-lg font-medium">Follow us on</span>
                    <div className="flex space-x-3">
                      <a href="#" className="">
                        <img
                          src={twitter}
                          alt="Twitter"
                          className="w-12 h-12"
                        />
                      </a>
                      <a href="#" className="">
                        <img src={fb} alt="Facebook" className="w-12 h-12" />
                      </a>
                      <a href="#" className="">
                        <img src={ig} alt="Instagram" className="w-12 h-12" />
                      </a>
                      <a href="#" className="">
                        <img src={yt} alt="YouTube" className="w-12 h-12" />
                      </a>
                    </div>
                  </div>
                </div>
              </div>
              <div className="copyright pb-3">
                <div className="text-sm text-center text-white">
                © Finroots Private Limited All rights reserved
                </div>
              </div>
            </div>
          </footer>
        </div>
      </div>
    </>
  );
}
